@@ -147,11 +147,14 @@ that depends on non-hashable arguments):
 
 $$memoize_uw
 
-Here i used the functools.update_wrapper_ utility, which has
+Here I used the functools.update_wrapper_ utility, which has
 been added in Python 2.5 expressly to simplify the definition of decorators
 (in older versions of Python you need to copy the function attributes
 ``__name__``, ``__doc__``, ``__module__`` and ``__dict__``
 from the original function to the decorated function by hand).
+Here is an example of usage:
+
+$$f1
 
 .. _functools.update_wrapper: https://docs.python.org/3/library/functools.html#functools.update_wrapper
 
@@ -611,11 +614,11 @@ having to rewrite them in terms of ``decorator``. You can use a
 
 $$decorator_apply
 
-``decorator_apply`` sets the attribute ``__wrapped__`` of the generated
-function to the original function, so that you can get the right
-source code. If you are using Python 3, you should also set the
-``__qualname__`` attribute to preserve the qualified name of the
-original function.
+``decorator_apply`` sets the attribute ``__wrapped__`` of the
+generated function to the original function, so that you can get the
+right source code. If you are using a Python more recent than 3.2, you
+should also set the ``__qualname__`` attribute to preserve the
+qualified name of the original function.
 
 Notice that I am not providing this functionality in the ``decorator``
 module directly since I think it is best to rewrite the decorator rather
@@ -1121,9 +1124,8 @@ You can check that the ``__annotations__`` dictionary is preserved:
 Here ``f.__wrapped__`` is the original undecorated function. Such an attribute
 is added to be consistent with the way ``functools.update_wrapper`` work.
 Another attribute which is copied from the original function is
-``__qualname__``, the qualified name. This is a concept introduced
-in Python 3. In Python 2 the decorator module will still add a
-qualified name, but its value will always be ``None``.
+``__qualname__``, the qualified name. This is an attribute which is
+present starting from Python 3.3.
 """
 
 import sys
@@ -1231,6 +1233,11 @@ def _memoize(func, *args, **kw):
 
 
 def memoize(f):
+    """
+    A simple memoize implementation. It works by adding a .cache dictionary
+    to the decorated function. The cache will grow indefinitely, so it is
+    your responsability to clear it, if needed.
+    """
     f.cache = {}
     return decorate(f, _memoize)
 
